@@ -20,27 +20,32 @@ import logging
 import offlineimap
 from offlineimap.ui.UIBase import UIBase
 
+
 class Basic(UIBase):
     """'Basic' simply sets log level to INFO."""
 
-    def __init__(self, config, loglevel = logging.INFO):
+    def __init__(self, config, loglevel=logging.INFO):
         return super(Basic, self).__init__(config, loglevel)
 
+
 class Quiet(UIBase):
     """'Quiet' simply sets log level to WARNING"""
-    def __init__(self, config, loglevel = logging.WARNING):
+
+    def __init__(self, config, loglevel=logging.WARNING):
         return super(Quiet, self).__init__(config, loglevel)
 
+
 class Syslog(UIBase):
     """'Syslog' sets log level to INFO and outputs to syslog instead of stdout"""
-    def __init__(self, config, loglevel = logging.INFO):
+
+    def __init__(self, config, loglevel=logging.INFO):
         return super(Syslog, self).__init__(config, loglevel)
 
     def setup_consolehandler(self):
         # create syslog handler
         ch = logging.handlers.SysLogHandler('/dev/log')
         # create formatter and add it to the handlers
-        self.formatter = logging.Formatter("%(message)s")
+        self.formatter = logging.Formatter("offlineimap[%(process)d]: %(message)s")
         ch.setFormatter(self.formatter)
         # add the handlers to the logger
         self.logger.addHandler(ch)
@@ -48,4 +53,4 @@ class Syslog(UIBase):
         return ch
 
     def setup_sysloghandler(self):
-        pass # Do not honor -s (log to syslog) CLI option.
+        pass  # Do not honor -s (log to syslog) CLI option.
